==> apache-hyracks-0.3.2-source-release.zip: apache-hyracks-0.3.2/hyracks/hyracks-dataflow-std/src/main/java/org/apache/hyracks/dataflow/std/map/ReflectionBasedDeserializedMapperFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.dataflow.std.map;

import org.apache.hyracks.api.exceptions.HyracksDataException;

public class ReflectionBasedDeserializedMapperFactory implements IDeserializedMapperFactory {
    private static final long serialVersionUID = 1L;

    private final Class<? extends IDeserializedMapper> mapperClass;

    public ReflectionBasedDeserializedMapperFactory(Class<? extends IDeserializedMapper> mapperClass) {
        this.mapperClass = mapperClass;
    }

    @Override
    public IDeserializedMapper createMapper() throws HyracksDataException {
        try {
            return mapperClass.newInstance();
        } catch (InstantiationException e) {
            throw new HyracksDataException(e);
        } catch (IllegalAccessException e) {
            throw new HyracksDataException(e);
        }
    }
}

==> apache-hyracks-0.3.7.1-source-release.zip: apache-hyracks-0.3.7.1/hyracks/hyracks-dataflow-std/src/main/java/org/apache/hyracks/dataflow/std/map/ReflectionBasedDeserializedMapperFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.hyracks.dataflow.std.map;

import org.apache.hyracks.api.exceptions.HyracksDataException;

public class ReflectionBasedDeserializedMapperFactory implements IDeserializedMapperFactory {
    private static final long serialVersionUID = 1L;

    private final Class<? extends IDeserializedMapper> mapperClass;

    public ReflectionBasedDeserializedMapperFactory(Class<? extends IDeserializedMapper> mapperClass) {
        this.mapperClass = mapperClass;
    }

    @Override
    public IDeserializedMapper createMapper() throws HyracksDataException {
        try {
            return mapperClass.newInstance();
        } catch (Exception e) {
            throw HyracksDataException.create(e);
        }
    }
}
